[jboss-cvs] JBossAS SVN: r83842 - in projects/ejb3/trunk/profile3_1: src/main/resources and 10 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Wed Feb 4 04:11:32 EST 2009


Author: jaikiran
Date: 2009-02-04 04:11:31 -0500 (Wed, 04 Feb 2009)
New Revision: 83842

Added:
   projects/ejb3/trunk/profile3_1/build-test.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb-container-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-connectors-jboss-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-interceptors-aop.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/transactionmanager-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/aop-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/ejb3-deployers-jboss-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/jpa-deployers-jboss-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/jndi.properties
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSB.java
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSBLocal.java
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/unit/Profile3_1_DeploymentTestCase.java
Removed:
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/aop-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/ejb3-deployers-jboss-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/jpa-deployers-jboss-beans.xml
   projects/ejb3/trunk/profile3_1/src/main/resources/conf/transactionmanager-beans.xml
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/NoInterfaceStatelessBean.java
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/TestRemote.java
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/unit/NoInterfaceBeanTestCase.java
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface/
   projects/ejb3/trunk/profile3_1/src/test/resources/jndi.properties
Modified:
   projects/ejb3/trunk/profile3_1/pom.xml
   projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/common/AbstractProfile3_1_TestCase.java
   projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap.xml
   projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap/maindeployer.xml
Log:
EJBTHREE-1711 Updated the test case and added support to generate the deployables (jar) for the testcase

Added: projects/ejb3/trunk/profile3_1/build-test.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/build-test.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/build-test.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,31 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<project default="main" name="Profile3_1 Tests">
+
+	<property name="target.dir" value="${basedir}/target" />
+	<property name="test.lib.dir" value="${target.dir}/test-lib" />
+	<property name="test.classes.dir" value="${target.dir}/tests-classes" />
+
+	<target name="main" depends="prepare">
+		<antcall target="jars" />
+	</target>
+
+	<target name="prepare" depends="clean">
+		<mkdir dir="${test.lib.dir}" />
+	</target>
+
+	<target name="clean">
+		<delete dir="${test.lib.dir}" />
+	</target>
+
+	<target name="jars" depends="ejb3-profile-test">
+	
+	</target>
+	
+	<target name="ejb3-profile-test">
+		<jar destfile="${test.lib.dir}/ejb3-profile-test.jar">
+			<fileset dir="${test.classes.dir}">
+					<include name="org/jboss/ejb3/profile3_1/test/deployment/**/*.class"/>
+			</fileset>
+		</jar>
+	</target>
+</project>
\ No newline at end of file

Modified: projects/ejb3/trunk/profile3_1/pom.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/pom.xml	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/pom.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -20,107 +20,168 @@
   <description>Profile3_1</description>
 
   <properties>
-    <version.org.jboss.ejb3.jboss-ejb3-embedded>1.0.0-Alpha1</version.org.jboss.ejb3.jboss-ejb3-embedded>
+    <version.org.jboss.ejb3.jboss-ejb3-embedded>1.0.0-SNAPSHOT</version.org.jboss.ejb3.jboss-ejb3-embedded>
     <version.org.jboss.deployers>2.0.3.GA</version.org.jboss.deployers>
     <version.org.jboss_jboss-vfs>2.0.1.GA</version.org.jboss_jboss-vfs>
     <version.org.jboss.bootstrap_jboss-bootstrap>0.1.0-SNAPSHOT</version.org.jboss.bootstrap_jboss-bootstrap>
     <version.org.jboss.jpa_jboss-jpa-deployers>1.0.0-Beta6</version.org.jboss.jpa_jboss-jpa-deployers>
   </properties>
   
+  <build>
+  	<plugins>
+      <!-- Let's build the test deployables through Ant -->
+      <plugin>
+        <groupId>org.apache.maven.plugins</groupId>
+        <artifactId>maven-antrun-plugin</artifactId>
+        <executions>
+          <execution>
+            <id>build-tests</id>
+            <goals>
+              <goal>run</goal>
+            </goals>
+            <phase>integration-test</phase>
+            <configuration>
+              <tasks>
+                <!-- Execute the Test Build -->
+                <ant antfile="build-test.xml" target="main" />
+              </tasks>
+            </configuration>
+          </execution>
+        </executions>
+      </plugin>
+      
+      <!-- Surefire plugin for integration tests -->
+      <plugin>
+      <artifactId>maven-surefire-plugin</artifactId>
+      <configuration>
+      	<!--  Disable unit tests -->
+        <skip>true</skip>
+         <redirectTestOutputToFile>true</redirectTestOutputToFile>
+         <printSummary>true</printSummary>
+         
+      </configuration>
+      <executions>
+        <execution>
+          <id>surefire-it</id>
+          <phase>integration-test</phase>
+          <goals>
+            <goal>test</goal>
+          </goals>
+          <configuration>
+            <skip>false</skip>
+            <additionalClasspathElements>
+            	<!--  The target/test-lib which we create contains the jars (deployables)
+            	which will be used by the tests -->
+              <additionalClasspathElement>
+                ${basedir}/target/test-lib
+              </additionalClasspathElement>
+            </additionalClasspathElements>
+          </configuration>
+        </execution>
+      </executions>
+    </plugin>
+     </plugins> 
   
-  	<dependencies>
-    <dependency>
-    	<groupId>org.jboss.ejb3</groupId>
-    	<artifactId>jboss-ejb3-embedded</artifactId>
-    	<version>${version.org.jboss.ejb3.jboss-ejb3-embedded}</version>
-    	 <exclusions>
-    		<exclusion>
-          		<groupId>org.jboss</groupId>
-          		<artifactId>jboss-vfs</artifactId>
-        	</exclusion>
-    		<exclusion>
-          		<groupId>org.jboss.deployers</groupId>
-          		<artifactId>jboss-deployers-vfs</artifactId>
-        	</exclusion>
-        	<exclusion>
-          		<groupId>org.jboss.deployers</groupId>
-          		<artifactId>jboss-deployers-core-spi</artifactId>
-        	</exclusion>
-			<exclusion>
-          		<groupId>org.jboss.deployers</groupId>
-          		<artifactId>jboss-deployers-impl</artifactId>
-        	</exclusion>
-			<exclusion>
-          		<groupId>org.jboss.deployers</groupId>
-          		<artifactId>jboss-deployers-structure-spi</artifactId>
-        	</exclusion>
-			<exclusion>
-          		<groupId>org.jboss.jbossas</groupId>
-          		<artifactId>jboss-as-bootstrap</artifactId>
-        	</exclusion>
-									        	
-    	</exclusions> 
-    </dependency>	
+  </build>
+  
+  
+	<dependencies>
+		<!--  EJB3 Embedded dependency. Needs to be removed once the
+		deployers in Embedded are moved to ejb3-deployers. EJBTHREE-1712 -->
+    	<dependency>
+	    	<groupId>org.jboss.ejb3</groupId>
+	    	<artifactId>jboss-ejb3-embedded</artifactId>
+	    	<version>${version.org.jboss.ejb3.jboss-ejb3-embedded}</version>
+	    	 <exclusions>
+	    		<exclusion>
+	          		<groupId>org.jboss</groupId>
+	          		<artifactId>jboss-vfs</artifactId>
+	        	</exclusion>
+	    		<exclusion>
+	          		<groupId>org.jboss.deployers</groupId>
+	          		<artifactId>jboss-deployers-vfs</artifactId>
+	        	</exclusion>
+	        	<exclusion>
+	          		<groupId>org.jboss.deployers</groupId>
+	          		<artifactId>jboss-deployers-core-spi</artifactId>
+	        	</exclusion>
+				<exclusion>
+	          		<groupId>org.jboss.deployers</groupId>
+	          		<artifactId>jboss-deployers-impl</artifactId>
+	        	</exclusion>
+				<exclusion>
+	          		<groupId>org.jboss.deployers</groupId>
+	          		<artifactId>jboss-deployers-structure-spi</artifactId>
+	        	</exclusion>
+				<exclusion>
+	          		<groupId>org.jboss.jbossas</groupId>
+	          		<artifactId>jboss-as-bootstrap</artifactId>
+	        	</exclusion>
+										        	
+	    	</exclusions> 
+	    </dependency>	
+    
     <!-- Bootstrap -->
-    <dependency>
-      <groupId>org.jboss.bootstrap</groupId>
-      <artifactId>jboss-bootstrap</artifactId>
-      <version>${version.org.jboss.bootstrap_jboss-bootstrap}</version>
-      <scope>test</scope>
-    </dependency>
-    <!-- JBoss deployers -->
-    <dependency>
-      <groupId>org.jboss.deployers</groupId>
-      <artifactId>jboss-deployers-vfs</artifactId>
-      <version>${version.org.jboss.deployers}</version>
-      <scope>test</scope>
-    </dependency>
+    	<dependency>
+	      <groupId>org.jboss.bootstrap</groupId>
+	      <artifactId>jboss-bootstrap</artifactId>
+	      <version>${version.org.jboss.bootstrap_jboss-bootstrap}</version>
+	      <scope>test</scope>
+	    </dependency>
     
-    <!-- EJB3 deployers -->
-   	<dependency>
-   	  <groupId>org.jboss.ejb3</groupId>
-   	  <artifactId>jboss-ejb3-deployers</artifactId>
-	  <version>0.1.1</version>
-   	</dependency>
-   	
-   	<dependency>
-   	  <groupId>org.jboss.jbossas</groupId>
-   	  <artifactId>jboss-as-ejb3</artifactId>
-	  <version>5.0.0.GA</version>
-   	</dependency>
-   	
-    <dependency>
-      	<groupId>org.jboss</groupId>
-      	<artifactId>jboss-vfs</artifactId>
-    	<version>${version.org.jboss_jboss-vfs}</version>
-    </dependency>
-   
-   
-   <dependency>
-      <groupId>org.jboss.deployers</groupId>
-      <artifactId>jboss-deployers-impl</artifactId>
-      <version>${version.org.jboss.deployers}</version>
-      
-    </dependency>
-    
-    <dependency>
-      <groupId>org.jboss.deployers</groupId>
-      <artifactId>jboss-deployers-structure-spi</artifactId>
-      <version>${version.org.jboss.deployers}</version>
-    </dependency>
-     
-     <dependency>
-      <groupId>org.jboss.deployers</groupId>
-      <artifactId>jboss-deployers-core-spi</artifactId>
-      <version>${version.org.jboss.deployers}</version>
-    </dependency>
-    
-    <!--  JPA deployers -->
-    <dependency>
-    	<groupId>org.jboss.jpa</groupId>
-    	<artifactId>jboss-jpa-deployers</artifactId>
-    	<version>${version.org.jboss.jpa_jboss-jpa-deployers}</version>
-    	<scope>runtime</scope>
-    </dependency>
+	    <!-- JBoss deployers -->
+	    <dependency>
+	      <groupId>org.jboss.deployers</groupId>
+	      <artifactId>jboss-deployers-vfs</artifactId>
+	      <version>${version.org.jboss.deployers}</version>
+	      <scope>test</scope>
+	    </dependency>
+	    
+	    <!-- EJB3 deployers -->
+	   	<dependency>
+	   	  <groupId>org.jboss.ejb3</groupId>
+	   	  <artifactId>jboss-ejb3-deployers</artifactId>
+		  <version>0.1.1</version>
+	   	</dependency>
+	   	
+	   	<dependency>
+	   	  <groupId>org.jboss.jbossas</groupId>
+	   	  <artifactId>jboss-as-ejb3</artifactId>
+		  <version>5.0.0.GA</version>
+	   	</dependency>
+	   	
+	    <dependency>
+	      	<groupId>org.jboss</groupId>
+	      	<artifactId>jboss-vfs</artifactId>
+	    	<version>${version.org.jboss_jboss-vfs}</version>
+	    </dependency>
+	   
+	   
+	   <dependency>
+	      <groupId>org.jboss.deployers</groupId>
+	      <artifactId>jboss-deployers-impl</artifactId>
+	      <version>${version.org.jboss.deployers}</version>
+	      
+	    </dependency>
+	    
+	    <dependency>
+	      <groupId>org.jboss.deployers</groupId>
+	      <artifactId>jboss-deployers-structure-spi</artifactId>
+	      <version>${version.org.jboss.deployers}</version>
+	    </dependency>
+	     
+	     <dependency>
+	      <groupId>org.jboss.deployers</groupId>
+	      <artifactId>jboss-deployers-core-spi</artifactId>
+	      <version>${version.org.jboss.deployers}</version>
+	    </dependency>
+	    
+	    <!--  JPA deployers -->
+	    <dependency>
+	    	<groupId>org.jboss.jpa</groupId>
+	    	<artifactId>jboss-jpa-deployers</artifactId>
+	    	<version>${version.org.jboss.jpa_jboss-jpa-deployers}</version>
+	    	<scope>runtime</scope>
+	    </dependency>
 	</dependencies>
 </project>

Deleted: projects/ejb3/trunk/profile3_1/src/main/resources/conf/aop-beans.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/aop-beans.xml	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/aop-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,12 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<deployment xmlns="urn:jboss:bean-deployer:2.0">
-
-<bean name="AspectManager" class="org.jboss.aop.AspectManager">
-      <constructor factoryClass="org.jboss.aop.AspectManager" factoryMethod="instance"/>
-   </bean>
-   
-   <bean name="AspectAppParsingDeployer" class="org.jboss.aop.deployers.AspectAppParsingDeployer"/>
-   <bean name="AspectDeployer" class="org.jboss.aop.deployers.AspectDeployer">
-      <property name="aspectManager"><inject bean="AspectManager"/></property>
-   </bean>
-</deployment>   
\ No newline at end of file

Added: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb-container-beans.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb-container-beans.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb-container-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,9 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+   <!-- The provider for EJB3 UserTransactions -->
+   <bean name="EJB3UserTransactionprovider" class="org.jboss.ejb3.tx.EJB3UserTransactionProvider">
+      <constructor factoryClass="org.jboss.ejb3.tx.EJB3UserTransactionProvider" factoryMethod="getSingleton"/>
+   </bean>
+   
+   <bean name="EmbeddedCachedConnectionManagerBridge" class="org.jboss.ejb3.embedded.connectionmanager.EmbeddedCachedConnectionManager"/>
+</deployment>


Property changes on: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb-container-beans.xml
___________________________________________________________________
Name: svn:executable
   + *

Copied: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-connectors-jboss-beans.xml (from rev 83796, projects/ejb3/trunk/core/src/main/resources/ejb3-connectors-jboss-beans.xml)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-connectors-jboss-beans.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-connectors-jboss-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,44 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+  
+  EJB3 Connectors
+  
+-->
+
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+
+  <!-- 
+    
+    JBoss Remoting Connector  
+    
+    Note: Bean Name "org.jboss.ejb3.RemotingConnector" is used
+    as a lookup value; alter only after checking java references
+    to this key.
+    
+  -->
+  <bean name="org.jboss.ejb3.RemotingConnector"
+    class="org.jboss.remoting.transport.Connector">
+
+    <property name="invokerLocator">socket://0.0.0.0:3873</property>
+
+    <property name="serverConfiguration">
+      <inject bean="ServerConfiguration" />
+    </property>
+  </bean>
+
+  <!-- Remoting Server Configuration -->
+  <bean name="ServerConfiguration"
+    class="org.jboss.remoting.ServerConfiguration">
+    <property name="invocationHandlers">
+      <map keyClass="java.lang.String" valueClass="java.lang.String">
+        <entry>
+          <key>AOP</key>
+          <value>
+            org.jboss.aspects.remoting.AOPRemotingInvocationHandler
+          </value>
+        </entry>
+      </map>
+    </property>
+  </bean>
+
+</deployment>

Copied: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-interceptors-aop.xml (from rev 83796, projects/ejb3/trunk/core/src/main/resources/ejb3-interceptors-aop.xml)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-interceptors-aop.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/ejb3-interceptors-aop.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,457 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<aop xmlns="urn:jboss:aop-beans:1.0">
+   <interceptor class="org.jboss.aspects.remoting.InvokeRemoteInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.security.client.SecurityClientInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.aspects.tx.ClientTxPropagationInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.remoting.IsLocalInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.remoting.ClusteredIsLocalInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.aspects.remoting.ClusterChooserInterceptor" scope="PER_VM"/>
+
+   <interceptor class="org.jboss.aspects.tx.TxPropagationInterceptor" scope="PER_VM"/>
+
+   <stack name="ServiceClientInterceptors">
+      <interceptor-ref name="org.jboss.ejb3.remoting.IsLocalInterceptor"/>
+      <interceptor-ref name="org.jboss.ejb3.security.client.SecurityClientInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.tx.ClientTxPropagationInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.InvokeRemoteInterceptor"/>
+   </stack>
+
+   <stack name="AsynchronousStatelessSessionClientInterceptors">
+      <interceptor-ref name="org.jboss.ejb3.remoting.IsLocalInterceptor"/>
+      <interceptor-ref name="org.jboss.ejb3.security.client.SecurityClientInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.tx.ClientTxPropagationInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.InvokeRemoteInterceptor"/>
+   </stack>
+
+   <stack name="AsynchronousStatefulSessionClientInterceptors">
+      <interceptor-ref name="org.jboss.ejb3.remoting.IsLocalInterceptor"/>
+      <interceptor-ref name="org.jboss.ejb3.security.client.SecurityClientInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.tx.ClientTxPropagationInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.InvokeRemoteInterceptor"/>
+   </stack>
+
+   <stack name="StatelessSessionClientInterceptors">
+      <interceptor-ref name="org.jboss.ejb3.remoting.IsLocalInterceptor"/> 
+      <interceptor-ref name="org.jboss.ejb3.security.client.SecurityClientInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.tx.ClientTxPropagationInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.InvokeRemoteInterceptor"/>
+   </stack>
+
+   <stack name="StatefulSessionClientInterceptors">
+      <interceptor-ref name="org.jboss.ejb3.remoting.IsLocalInterceptor"/>
+      <interceptor-ref name="org.jboss.ejb3.security.client.SecurityClientInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.tx.ClientTxPropagationInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.InvokeRemoteInterceptor"/>
+   </stack>
+
+   <stack name="ClusteredStatelessSessionClientInterceptors">
+      <interceptor-ref name="org.jboss.ejb3.remoting.ClusteredIsLocalInterceptor"/>
+      <interceptor-ref name="org.jboss.ejb3.security.client.SecurityClientInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.tx.ClientTxPropagationInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.ClusterChooserInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.InvokeRemoteInterceptor"/>
+   </stack>
+
+   <stack name="ClusteredStatefulSessionClientInterceptors">
+      <interceptor-ref name="org.jboss.ejb3.remoting.ClusteredIsLocalInterceptor"/>
+      <interceptor-ref name="org.jboss.ejb3.security.client.SecurityClientInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.tx.ClientTxPropagationInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.ClusterChooserInterceptor"/>
+      <interceptor-ref name="org.jboss.aspects.remoting.InvokeRemoteInterceptor"/>
+   </stack>
+
+   <interceptor class="org.jboss.aspects.currentinvocation.CurrentInvocationInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.asynchronous.AsynchronousInterceptor" scope="PER_CLASS"/>
+   <interceptor class="org.jboss.ejb3.ENCPropagationInterceptor" scope="PER_VM"/>
+   <interceptor name="Basic Authorization" factory="org.jboss.ejb3.security.RoleBasedAuthorizationInterceptorFactory" scope="PER_CLASS"/>
+   <interceptor name="JACC Authorization" factory="org.jboss.ejb3.security.JaccAuthorizationInterceptorFactory" scope="PER_CLASS"/>
+   <interceptor factory="org.jboss.ejb3.security.AuthenticationInterceptorFactory" scope="PER_CLASS"/>
+   <interceptor factory="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory" scope="PER_CLASS"/>
+   <interceptor class="org.jboss.ejb3.entity.ExtendedPersistenceContextPropagationInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.stateless.StatelessInstanceInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.stateful.StatefulInstanceInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.stateful.SessionSynchronizationInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.service.ServiceSingletonInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.cache.StatefulReplicationInterceptor" scope="PER_VM"/>
+   <interceptor factory="org.jboss.ejb3.stateful.StatefulRemoveFactory" scope="PER_CLASS_JOINPOINT"/>
+   <interceptor factory="org.jboss.ejb3.tx.BMTTxInterceptorFactory" scope="PER_CLASS_JOINPOINT"/>
+   <interceptor factory="org.jboss.ejb3.tx.CMTTxInterceptorFactory" scope="PER_CLASS_JOINPOINT"/>
+   <!-- interceptor factory="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory" scope="PER_CLASS_JOINPOINT"/ -->
+   <interceptor factory="org.jboss.ejb3.remoting.ReplicantsManagerInterceptorFactory" scope="PER_CLASS"/>
+   <interceptor class="org.jboss.ejb3.AllowedOperationsInterceptor" scope="PER_VM"/>
+   <interceptor factory="org.jboss.ejb3.mdb.CurrentMessageInjectorInterceptorFactory" scope="PER_CLASS"/>
+   <interceptor class="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor" scope="PER_VM"/>
+   <interceptor class="org.jboss.ejb3.BlockContainerShutdownInterceptor" scope="PER_VM"/>
+   <interceptor factory="org.jboss.ejb3.connectionmanager.CachedConnectionInterceptorFactory" scope="PER_CLASS"/>
+
+   <!--
+         INTERCEPTORS
+     -->
+   
+   <aspect name="InjectInterceptorsFactory" factory="org.jboss.ejb3.interceptors.aop.InjectInterceptorsFactory" scope="PER_JOINPOINT"/>
+   <aspect name="InterceptorsFactory" factory="org.jboss.ejb3.interceptors.aop.InterceptorsFactory" scope="PER_INSTANCE"/>
+   <aspect name="InvocationContextInterceptor" class="org.jboss.ejb3.interceptors.aop.InvocationContextInterceptor" scope="PER_VM"/>
+
+   <!-- TODO: this is actually the bootstrap container -->
+   <domain name="Intercepted Bean">
+      <pointcut name="beanAroundInvokeCallbackMethods" expr="execution(* @org.jboss.ejb3.interceptors.ManagedObject->@javax.interceptor.AroundInvoke(..))"/>
+      <pointcut name="beanPostConstructCallbackMethods" expr="execution(* @org.jboss.ejb3.interceptors.ManagedObject->@javax.interceptor.PostConstruct(..))"/>
+      <pointcut name="beanPreDestroyCallbackMethods" expr="execution(* @org.jboss.ejb3.interceptors.ManagedObject->@javax.interceptor.PreDestroy(..))"/>
+      
+      <pointcut name="beanLifecycleCallbackMethods" expr="beanAroundInvokeCallbackMethods OR beanPostConstructCallbackMethods OR beanPreDestroyCallbackMethods"/>
+      
+      <!-- Prepare for dynamic AOP -->
+      <!-- TODO: optimize, we only need managed objects (and interceptors!) to be aspectized -->
+      <!-- prepare expr="all(*) AND has(@org.jboss.ejb3.interceptors.ManagedObject->new(..))"/ -->
+      <!-- TODO: let's see if we can do without 
+      <prepare expr="all(*)"/>
+      -->
+      
+      <!-- Setup AOP interceptors based on spec interceptors -->
+      <bind pointcut="construction(@org.jboss.ejb3.interceptors.ManagedObject->new(..))">
+         <!-- interceptor-ref name="LoggingInterceptor"/ -->
+         <!-- TODO: we don't need invocation context here -->
+         <!-- TODO: we do until we've seperated the post constructs -->
+         <advice name="setup" aspect="InvocationContextInterceptor"/>
+         <advice name="invoke" aspect="InterceptorsFactory"/>
+      </bind>
+      
+      <!-- Lifecycle Event Callbacks (EJB 3 12.4) -->
+      
+      <!-- TODO: for now handled in EJBContainer.invokePostConstruct until injection is refactored 
+      <bind pointcut="construction(@org.jboss.ejb3.interceptors.ManagedObject->new(..))">
+         <advice name="setup" aspect="InvocationContextInterceptor"/>
+         <advice name="postConstruct" aspect="InjectInterceptorsFactory"/>
+      </bind>
+      -->
+      
+      <!-- this is the usual way, now we move it into the other domains, because the
+           invocation of EJB interceptors must be the last in the chain 
+      <bind pointcut="execution(* @org.jboss.ejb3.interceptors.ManagedObject->*(..)) AND !beanLifecycleCallbackMethods">
+         <advice name="setup" aspect="InvocationContextInterceptor"/>
+         <advice name="fillMethod" aspect="InvocationContextInterceptor"/>
+         <advice name="aroundInvoke" aspect="InjectInterceptorsFactory"/>
+      </bind>
+      -->
+      <stack name="EJBInterceptors">
+         <interceptor-ref name="org.jboss.ejb3.connectionmanager.CachedConnectionInterceptorFactory"/>
+         
+         <advice name="setup" aspect="InvocationContextInterceptor"/>
+         <advice name="fillMethod" aspect="InvocationContextInterceptor"/>
+         <advice name="aroundInvoke" aspect="InjectInterceptorsFactory"/>
+      </stack>
+      
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.aspects.currentinvocation.CurrentInvocationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.BlockContainerShutdownInterceptor"/>
+      </bind>
+      
+      <stack name="LifecycleCallbackStack">
+         <interceptor-ref name="org.jboss.aspects.currentinvocation.CurrentInvocationInterceptor"/>
+         <advice name="setup" aspect="InvocationContextInterceptor"/>
+      </stack>
+   </domain>
+   
+   
+   
+   <domain name="Stateless Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.asynchronous.AsynchronousInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.ENCPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.security.AuthenticationInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.SecurityDomain->*(..))">
+         <interceptor-ref name="Basic Authorization"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.Clustered->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.remoting.ReplicantsManagerInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.aspects.tx.TxPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.stateless.StatelessInstanceInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Pool)">
+         @org.jboss.ejb3.annotation.Pool (value="ThreadlocalPool", maxSize=30, timeout=10000)
+      </annotation>
+   </domain>
+
+   <domain name="JACC Stateless Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.asynchronous.AsynchronousInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.ENCPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.security.AuthenticationInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.SecurityDomain->*(..))">
+         <interceptor-ref name="JACC Authorization"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.Clustered->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.remoting.ReplicantsManagerInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.aspects.tx.TxPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.stateless.StatelessInstanceInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Pool)">
+         @org.jboss.ejb3.annotation.Pool (value="ThreadlocalPool", maxSize=30, timeout=10000)
+      </annotation>
+   </domain>
+
+   <domain name="Base Stateful Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.asynchronous.AsynchronousInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.ENCPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.security.AuthenticationInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.SecurityDomain->*(..))">
+         <interceptor-ref name="Basic Authorization"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.Clustered->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.remoting.ReplicantsManagerInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.aspects.tx.TxPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->@javax.ejb.Remove(..))">
+         <interceptor-ref name="org.jboss.ejb3.stateful.StatefulRemoveFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.stateful.StatefulInstanceInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+      </bind>
+      <bind pointcut="execution(public * $instanceof{javax.ejb.SessionSynchronization}->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.stateful.SessionSynchronizationInterceptor"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.ExtendedPersistenceContextPropagationInterceptor"/>
+      </bind>
+
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.Clustered->*(..)) AND !execution(public * *->@javax.ejb.Remove(..))">
+         <interceptor-ref name="org.jboss.ejb3.cache.StatefulReplicationInterceptor"/>
+      </bind>
+
+      <bind pointcut="execution(public * *->*(..))">
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Pool)">
+         @org.jboss.ejb3.annotation.Pool (value="ThreadlocalPool", maxSize=30, timeout=10000)
+      </annotation>
+   </domain>
+
+   <domain name="Stateful Bean" extends="Base Stateful Bean" inheritBindings="true">
+      <!-- NON Clustered cache configuration -->
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Cache) AND !class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.Cache ("SimpleStatefulCache")
+      </annotation>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.PersistenceManager) AND !class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.PersistenceManager ("StatefulSessionFilePersistenceManager")
+      </annotation>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.CacheConfig) AND !class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.CacheConfig (maxSize=100000, idleTimeoutSeconds=300, removalTimeoutSeconds=0)
+      </annotation>
+
+      <!-- Clustered cache configuration -->
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Cache) AND class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.Cache ("StatefulTreeCache")
+      </annotation>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.CacheConfig) AND class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.CacheConfig (name="sfsb-cache", maxSize=100000, idleTimeoutSeconds=300, removalTimeoutSeconds=0)
+      </annotation>
+   </domain>
+
+   <domain name="JACC Stateful Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.asynchronous.AsynchronousInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.ENCPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.security.AuthenticationInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.SecurityDomain->*(..))">
+         <interceptor-ref name="JACC Authorization"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.Clustered->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.remoting.ReplicantsManagerInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.aspects.tx.TxPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->@javax.ejb.Remove(..))">
+         <interceptor-ref name="org.jboss.ejb3.stateful.StatefulRemoveFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.stateful.StatefulInstanceInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+      </bind>
+      <bind pointcut="execution(public * $instanceof{javax.ejb.SessionSynchronization}->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.stateful.SessionSynchronizationInterceptor"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.ExtendedPersistenceContextPropagationInterceptor"/>
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.Clustered->*(..)) AND !execution(public * *->@javax.ejb.Remove(..))">
+         <interceptor-ref name="org.jboss.ejb3.cache.StatefulReplicationInterceptor"/>
+      </bind>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Pool)">
+         @org.jboss.ejb3.annotation.Pool (value="ThreadlocalPool", maxSize=30, timeout=10000)
+      </annotation>
+
+      <!-- NON Clustered cache configuration -->
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Cache) AND !class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.Cache ("SimpleStatefulCache")
+      </annotation>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.PersistenceManager) AND !class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.PersistenceManager ("StatefulSessionFilePersistenceManager")
+      </annotation>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.CacheConfig) AND !class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.CacheConfig (maxSize=100000, idleTimeoutSeconds=300, removalTimeoutSeconds=0)
+      </annotation>
+
+      <!-- Clustered cache configuration -->
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Cache) AND class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.Cache ("StatefulTreeCache")
+      </annotation>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.CacheConfig) AND class(@org.jboss.ejb3.annotation.Clustered)">
+         @org.jboss.ejb3.annotation.CacheConfig (name="sfsb-cache", maxSize=100000, idleTimeoutSeconds=300, removalTimeoutSeconds=0)
+      </annotation>
+   </domain>
+
+   <domain name="Embedded Stateful Bean" extends="Base Stateful Bean" inheritBindings="true">
+      <!-- NON Clustered cache configuration -->
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Cache)">
+         @org.jboss.ejb3.annotation.Cache ("NoPassivationCache")
+      </annotation>
+
+   </domain>
+
+   <domain name="Message Driven Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.security.AuthenticationInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <!-- TODO: Authorization? -->
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.stateless.StatelessInstanceInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Pool)">
+         @org.jboss.ejb3.annotation.Pool (value="StrictMaxPool", maxSize=15, timeout=10000)
+      </annotation>
+   </domain>
+
+   <domain name="Consumer Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.stateless.StatelessInstanceInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..)) AND (has(* *->@org.jboss.ejb3.annotation.CurrentMessage(..)) OR hasfield(* *->@org.jboss.ejb3.annotation.CurrentMessage))">
+         <interceptor-ref name="org.jboss.ejb3.mdb.CurrentMessageInjectorInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+      <annotation expr="!class(@org.jboss.ejb3.annotation.Pool)">
+         @org.jboss.ejb3.annotation.Pool (value="StrictMaxPool", maxSize=15, timeout=10000)
+      </annotation>
+   </domain>
+
+   <domain name="Service Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.asynchronous.AsynchronousInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.ENCPropagationInterceptor"/>
+      </bind>
+      <bind pointcut="!execution(* *->create()) AND !execution(* *->start()) AND !execution(*->new(..)) AND !execution(* *->stop()) AND !execution(* *->destroy())">
+         <interceptor-ref name="org.jboss.ejb3.security.AuthenticationInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.SecurityDomain->*(..)) AND !execution(* *->create()) AND !execution(* *->start()) AND !execution(* *->stop()) AND !execution(* *->destroy())">
+         <interceptor-ref name="Basic Authorization"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..)) AND !execution(* *->create()) AND !execution(* *->start()) AND !execution(* *->stop()) AND !execution(* *->destroy())">
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.aspects.tx.TxPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..)) AND !execution(* *->create()) AND !execution(* *->start()) AND !execution(* *->stop())">
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+   </domain>
+
+   <domain name="JACC Service Bean" extends="Intercepted Bean" inheritBindings="true">
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.ejb3.asynchronous.AsynchronousInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.ENCPropagationInterceptor"/>
+      </bind>
+      <bind pointcut="!execution(* *->create()) AND !execution(* *->start()) AND !execution(*->new(..)) AND !execution(* *->stop()) AND !execution(* *->destroy())">
+         <interceptor-ref name="org.jboss.ejb3.security.AuthenticationInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * @org.jboss.ejb3.annotation.SecurityDomain->*(..)) AND !execution(* *->create()) AND !execution(* *->start()) AND !execution(* *->stop()) AND !execution(* *->destroy())">
+         <interceptor-ref name="Basic Authorization"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..)) AND !execution(* *->create()) AND !execution(* *->start()) AND !execution(* *->destroy())">
+         <interceptor-ref name="org.jboss.ejb3.security.RunAsSecurityInterceptorFactory"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..))">
+         <interceptor-ref name="org.jboss.aspects.tx.TxPropagationInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.CMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.tx.BMTTxInterceptorFactory"/>
+         <interceptor-ref name="org.jboss.ejb3.AllowedOperationsInterceptor"/>
+         <interceptor-ref name="org.jboss.ejb3.entity.TransactionScopedEntityManagerInterceptor"/>
+      </bind>
+      <bind pointcut="execution(public * *->*(..)) AND !execution(* *->create()) AND !execution(* *->start())">
+         <!-- interceptor-ref name="org.jboss.ejb3.interceptor.EJB3InterceptorsFactory"/ -->
+         <stack-ref name="EJBInterceptors"/>
+      </bind>
+   </domain>
+
+</aop>
\ No newline at end of file

Copied: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/transactionmanager-beans.xml (from rev 83796, projects/ejb3/trunk/profile3_1/src/main/resources/conf/transactionmanager-beans.xml)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/transactionmanager-beans.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/deploy/transactionmanager-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,13 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+   <!-- JTA -->
+   <bean name="TransactionManager" class="org.jboss.ejb3.embedded.service.SimpleTransactionService">
+      <depends>NamingServer</depends>
+   </bean>
+   
+   <bean name="RealTransactionManager">
+      <constructor factoryMethod="getTransactionManager">
+         <factory bean="TransactionManager"/>
+      </constructor>
+   </bean>
+</deployment>

Copied: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/aop-beans.xml (from rev 83796, projects/ejb3/trunk/profile3_1/src/main/resources/conf/aop-beans.xml)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/aop-beans.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/aop-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,12 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+
+<bean name="AspectManager" class="org.jboss.aop.AspectManager">
+      <constructor factoryClass="org.jboss.aop.AspectManager" factoryMethod="instance"/>
+   </bean>
+   
+   <bean name="AspectAppParsingDeployer" class="org.jboss.aop.deployers.AspectAppParsingDeployer"/>
+   <bean name="AspectDeployer" class="org.jboss.aop.deployers.AspectDeployer">
+      <property name="aspectManager"><inject bean="AspectManager"/></property>
+   </bean>
+</deployment>   
\ No newline at end of file

Copied: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/ejb3-deployers-jboss-beans.xml (from rev 83796, projects/ejb3/trunk/profile3_1/src/main/resources/conf/ejb3-deployers-jboss-beans.xml)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/ejb3-deployers-jboss-beans.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/ejb3-deployers-jboss-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,131 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+
+<!--  EJB3 Embedded deployers
+	If more deployers are needed (from ejb3-deployers or as->ejb3) then they will be added as per requirement
+
+ -->
+   <!-- TODO: move SchemaResolverConfig to a more general beans.xml -->
+   <bean name="SchemaResolverConfig" class="org.jboss.xb.binding.sunday.unmarshalling.SchemaResolverConfig">
+      <property name="bindingClassesByLocations">
+         <map keyClass="java.lang.String" valueClass="java.lang.String">
+            <entry>
+               <key>ejb-jar_3_0.xsd</key>
+               <value>org.jboss.metadata.ejb.spec.EjbJar30MetaData</value>
+            </entry>
+            <entry>
+               <key>jboss_5_0.xsd</key>
+               <value>org.jboss.metadata.ejb.jboss.JBoss50MetaData</value>
+            </entry>
+            <entry>
+               <key>persistence_1_0.xsd</key>
+               <value>org.jboss.metadata.jpa.spec.PersistenceMetaData</value>
+            </entry>
+         </map>
+      </property>
+   </bean>
+   
+   <bean name="EjbParsingDeployer" class="org.jboss.ejb3.embedded.deployers.EjbParsingDeployer">
+      <!-- We need to be fast, so no schema validation -->
+      <property name="useSchemaValidation">false</property>
+   </bean>
+   <bean name="JBossEjbParsingDeployer" class="org.jboss.ejb3.embedded.deployers.JBossEjbParsingDeployer">
+      <!-- We need to be fast, so no schema validation -->
+      <property name="useSchemaValidation">false</property>
+   </bean>
+   <bean name="EjbAnnotationMetaDataDeployer" class="org.jboss.ejb3.embedded.deployers.EjbAnnotationMetaDataDeployer"/>
+   
+   <bean name="MergedJBossMetaDataDeployer" class="org.jboss.ejb3.embedded.deployers.MergedJBossMetaDataDeployer"/>
+   
+   <bean name="EjbMetadataJndiPolicyDecoratorDeployer" class="org.jboss.ejb3.embedded.deployers.EjbMetadataJndiPolicyDecoratorDeployer"/>
+   
+   <!-- EJB3 ProcessorChain Deployer -->
+   <bean name="Ejb3MetadataProcessingDeployer" class="org.jboss.ejb3.deployers.Ejb3MetadataProcessingDeployer" />
+   
+     <bean name="EjbModuleDeployer" class="org.jboss.ejb3.embedded.deployers.EjbModuleDeployer"/>  
+   <bean name="EjbComponentDeployer" class="org.jboss.ejb3.embedded.deployers.EjbComponentDeployer"/>
+
+   <bean name="MessageDestinationReferenceResolver" class="org.jboss.ejb3.embedded.resolvers.EmbeddedMessageDestinationReferenceResolver"/>
+   
+   <!-- EJB3 Cache Factory Registry -->
+   <bean name="EJB3CacheFactoryRegistry" class="org.jboss.ejb3.cache.CacheFactoryRegistry">
+      <property name="factories">
+         <!-- Define each of the registered factories -->
+         <map class="java.util.HashMap" keyClass="java.lang.String"
+            valueClass="java.lang.Class">
+            <!-- NoPassivationCache -->
+            <entry>
+               <key>NoPassivationCache</key>
+               <value>org.jboss.ejb3.cache.NoPassivationCacheFactory</value>
+            </entry>
+            <!-- SimpleStatefulCache -->
+            <entry>
+               <key>SimpleStatefulCache</key>
+               <value>org.jboss.ejb3.cache.simple.SimpleStatefulCacheFactory</value>
+            </entry>
+            <!-- StatefulTreeCache -->
+            <entry>
+               <key>StatefulTreeCache</key>
+               <value>org.jboss.ejb3.cache.tree.StatefulTreeCacheFactory</value>
+            </entry>
+         </map>
+      </property>
+   </bean>
+   
+   <!-- EJB3 Persistence Manager Factory Registry -->
+   <bean name="EJB3PersistenceManagerFactoryRegistry" class="org.jboss.ejb3.cache.persistence.PersistenceManagerFactoryRegistry">
+      <property name="factories">
+         <!-- Define each of the registered factories -->
+         <map class="java.util.HashMap" keyClass="java.lang.String"
+            valueClass="java.lang.Class">
+            <!-- StatefulSessionFilePersistenceManager -->
+            <entry>
+               <key>StatefulSessionFilePersistenceManager</key>
+               <value>org.jboss.ejb3.cache.simple.StatefulSessionFilePersistenceManagerFactory</value>
+            </entry>
+         </map>
+      </property>
+   </bean>
+   
+   <!-- EJB3 Pool Factory Registry -->
+   <bean name="EJB3PoolFactoryRegistry" class="org.jboss.ejb3.pool.PoolFactoryRegistry">
+      <property name="factories">
+         <!-- Define each of the registered factories -->
+         <map class="java.util.HashMap" keyClass="java.lang.String"
+            valueClass="java.lang.Class">
+            <!-- ThreadlocalPool -->
+            <entry>
+               <key>ThreadlocalPool</key>
+               <value>org.jboss.ejb3.pool.ThreadlocalPoolFactory</value>
+            </entry>
+            <!-- StrictMaxPool -->
+            <entry>
+               <key>StrictMaxPool</key>
+               <value>org.jboss.ejb3.pool.StrictMaxPoolFactory</value>
+            </entry>
+         </map>
+      </property>
+   </bean>
+   
+   <!-- SFSB JNDI Registrar -->
+   <bean name="org.jboss.ejb3.JndiRegistrar.Session.SFSBJndiRegistrar"
+      class="org.jboss.ejb3.proxy.jndiregistrar.JndiStatefulSessionRegistrar">
+      <constructor>
+         <parameter>
+            org.jboss.ejb3.proxy.objectfactory.session.stateful.StatefulSessionProxyObjectFactory
+         </parameter>
+      </constructor>
+   </bean>
+
+   <!-- SLSB JNDI Registrar -->
+   <bean name="org.jboss.ejb3.JndiRegistrar.Session.SLSBJndiRegistrar"
+      class="org.jboss.ejb3.proxy.jndiregistrar.JndiStatelessSessionRegistrar">
+      <constructor>
+         <parameter>
+            org.jboss.ejb3.proxy.objectfactory.session.stateless.StatelessSessionProxyObjectFactory
+         </parameter>
+      </constructor>
+   </bean>
+     
+     
+</deployment>
\ No newline at end of file

Copied: projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/jpa-deployers-jboss-beans.xml (from rev 83796, projects/ejb3/trunk/profile3_1/src/main/resources/conf/jpa-deployers-jboss-beans.xml)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/jpa-deployers-jboss-beans.xml	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/deployers/jpa-deployers-jboss-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,96 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<deployment xmlns="urn:jboss:bean-deployer:2.0">
+   <bean name="DataSourceDependencyResolver" class="org.jboss.as.jpa.resolvers.JBossASDataSourceDependencyResolver"/>
+   
+   <bean name="JavaEEModuleInformer" class="org.jboss.as.javaee.SimpleJavaEEModuleInformer"/>
+   
+   <bean name="JBossSearchStrategy" class="org.jboss.jpa.resolvers.strategy.JBossSearchStrategy"/>
+   
+   <bean name="SpecCompliantSearchStrategy" class="org.jboss.jpa.resolvers.strategy.SpecCompliantSearchStrategy"/>
+   
+   <!--
+      Can be DefaultPersistenceUnitDependencyResolver for spec compliant resolving, 
+      InterApplicationPersistenceUnitDependencyResolver for resolving beyond EARs,
+      or DynamicPersistencePersistenceUnitDependencyResolver which allows configuration via JMX.
+   -->
+   <bean name="PersistenceUnitDependencyResolver" class="org.jboss.jpa.resolvers.DynamicPersistenceUnitDependencyResolver"/>
+   
+   <bean name="XPCResolver" class="org.jboss.ejb3.stateful.EJB3XPCResolver"/>
+   
+   <bean name="PersistenceParsingDeployer" class="org.jboss.jpa.deployers.PersistenceParsingDeployer"/>
+
+   <bean name="PersistenceDeployer" class="org.jboss.jpa.deployers.PersistenceDeployer"/>
+   <bean name="PersistenceUnitDeployer" class="org.jboss.jpa.deployers.PersistenceUnitDeployer">
+      <property name="defaultPersistenceProperties">
+         <map keyClass="java.lang.String" valueClass="java.lang.String">
+            <entry>
+               <key>hibernate.transaction.manager_lookup_class</key>
+               <value>org.hibernate.transaction.JBossTransactionManagerLookup</value>
+            </entry>
+            <!--entry>
+               <key>hibernate.connection.release_mode</key>
+               <value>after_statement</value>
+            </entry-->
+            <!--entry>
+               <key>hibernate.transaction.flush_before_completion</key>
+               <value>false</value>
+            </entry-->
+            <!--entry>
+               <key>hibernate.transaction.auto_close_session</key>
+               <value>false</value>
+            </entry-->
+            <!--entry>
+               <key>hibernate.query.factory_class</key>
+               <value>org.hibernate.hql.ast.ASTQueryTranslatorFactory</value>
+            </entry-->
+            <!--entry>
+               <key>hibernate.hbm2ddl.auto</key>
+               <value>create-drop</value>
+            </entry-->
+            <entry>
+               <key>hibernate.cache.provider_class</key>
+               <value>org.hibernate.cache.HashtableCacheProvider</value>
+            </entry>
+            <!-- Clustered cache with JBoss Cache -->
+            <!--entry>
+               <key>hibernate.cache.region.factory_class</key>
+               <value>org.hibernate.cache.jbc2.JndiMultiplexedJBossCacheRegionFactory</value>
+            </entry>
+            <entry>
+               <key>hibernate.cache.region.jbc2.cachefactory</key>
+               <value>java:CacheManager</value>
+            </entry>
+            <entry>
+               <key>hibernate.cache.region.jbc2.cfg.entity</key>
+               <value>pessimistic-entity</value>
+            </entry>
+            <entry>
+               <key>hibernate.cache.region.jbc2.cfg.query</key>
+               <value>local-query</value>
+            </entry-->
+            <!--entry>
+               <key>hibernate.dialect</key>
+               <value>org.hibernate.dialect.HSQLDialect</value>
+            </entry-->
+            <entry>
+               <key>hibernate.jndi.java.naming.factory.initial</key>
+               <value>org.jnp.interfaces.NamingContextFactory</value>
+            </entry>
+            <entry>
+               <key>hibernate.jndi.java.naming.factory.url.pkgs</key>
+               <value>org.jboss.naming:org.jnp.interfaces</value>
+            </entry>
+            <entry>
+               <key>hibernate.bytecode.use_reflection_optimizer</key>
+               <value>false</value>
+            </entry>
+            <!-- I don't think this is honored, but EJB3Deployer uses it -->
+            <entry>
+               <key>hibernate.bytecode.provider</key>
+               <value>javassist</value>
+            </entry>
+         </map>
+      </property>
+   </bean>
+</deployment>

Deleted: projects/ejb3/trunk/profile3_1/src/main/resources/conf/ejb3-deployers-jboss-beans.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/ejb3-deployers-jboss-beans.xml	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/ejb3-deployers-jboss-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,130 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<deployment xmlns="urn:jboss:bean-deployer:2.0">
-
-<!--  EJB3 Embedded deployers
-	If more deployers are needed (from ejb3-deployers or as->ejb3) then they will be added as per requirement
-
- -->
-   <!-- TODO: move SchemaResolverConfig to a more general beans.xml -->
-   <bean name="SchemaResolverConfig" class="org.jboss.xb.binding.sunday.unmarshalling.SchemaResolverConfig">
-      <property name="bindingClassesByLocations">
-         <map keyClass="java.lang.String" valueClass="java.lang.String">
-            <entry>
-               <key>ejb-jar_3_0.xsd</key>
-               <value>org.jboss.metadata.ejb.spec.EjbJar30MetaData</value>
-            </entry>
-            <entry>
-               <key>jboss_5_0.xsd</key>
-               <value>org.jboss.metadata.ejb.jboss.JBoss50MetaData</value>
-            </entry>
-            <entry>
-               <key>persistence_1_0.xsd</key>
-               <value>org.jboss.metadata.jpa.spec.PersistenceMetaData</value>
-            </entry>
-         </map>
-      </property>
-   </bean>
-   
-   <bean name="EjbParsingDeployer" class="org.jboss.ejb3.embedded.deployers.EjbParsingDeployer">
-      <!-- We need to be fast, so no schema validation -->
-      <property name="useSchemaValidation">false</property>
-   </bean>
-   <bean name="JBossEjbParsingDeployer" class="org.jboss.ejb3.embedded.deployers.JBossEjbParsingDeployer">
-      <!-- We need to be fast, so no schema validation -->
-      <property name="useSchemaValidation">false</property>
-   </bean>
-   <bean name="EjbAnnotationMetaDataDeployer" class="org.jboss.ejb3.embedded.deployers.EjbAnnotationMetaDataDeployer"/>
-   
-   <bean name="MergedJBossMetaDataDeployer" class="org.jboss.ejb3.embedded.deployers.MergedJBossMetaDataDeployer"/>
-   
-   <bean name="EjbMetadataJndiPolicyDecoratorDeployer" class="org.jboss.ejb3.embedded.deployers.EjbMetadataJndiPolicyDecoratorDeployer"/>
-   
-   <!-- EJB3 ProcessorChain Deployer -->
-   <bean name="Ejb3MetadataProcessingDeployer" class="org.jboss.ejb3.deployers.Ejb3MetadataProcessingDeployer" />
-   
-   <bean name="EjbModuleDeployer" class="org.jboss.ejb3.embedded.deployers.EjbModuleDeployer"/>
-   <bean name="EjbComponentDeployer" class="org.jboss.ejb3.embedded.deployers.EjbComponentDeployer"/>
-
-   <bean name="MessageDestinationReferenceResolver" class="org.jboss.ejb3.embedded.resolvers.EmbeddedMessageDestinationReferenceResolver"/>
-   
-   <!-- EJB3 Cache Factory Registry -->
-   <bean name="EJB3CacheFactoryRegistry" class="org.jboss.ejb3.cache.CacheFactoryRegistry">
-      <property name="factories">
-         <!-- Define each of the registered factories -->
-         <map class="java.util.HashMap" keyClass="java.lang.String"
-            valueClass="java.lang.Class">
-            <!-- NoPassivationCache -->
-            <entry>
-               <key>NoPassivationCache</key>
-               <value>org.jboss.ejb3.cache.NoPassivationCacheFactory</value>
-            </entry>
-            <!-- SimpleStatefulCache -->
-            <entry>
-               <key>SimpleStatefulCache</key>
-               <value>org.jboss.ejb3.cache.simple.SimpleStatefulCacheFactory</value>
-            </entry>
-            <!-- StatefulTreeCache -->
-            <entry>
-               <key>StatefulTreeCache</key>
-               <value>org.jboss.ejb3.cache.tree.StatefulTreeCacheFactory</value>
-            </entry>
-         </map>
-      </property>
-   </bean>
-   
-   <!-- EJB3 Persistence Manager Factory Registry -->
-   <bean name="EJB3PersistenceManagerFactoryRegistry" class="org.jboss.ejb3.cache.persistence.PersistenceManagerFactoryRegistry">
-      <property name="factories">
-         <!-- Define each of the registered factories -->
-         <map class="java.util.HashMap" keyClass="java.lang.String"
-            valueClass="java.lang.Class">
-            <!-- StatefulSessionFilePersistenceManager -->
-            <entry>
-               <key>StatefulSessionFilePersistenceManager</key>
-               <value>org.jboss.ejb3.cache.simple.StatefulSessionFilePersistenceManagerFactory</value>
-            </entry>
-         </map>
-      </property>
-   </bean>
-   
-   <!-- EJB3 Pool Factory Registry -->
-   <bean name="EJB3PoolFactoryRegistry" class="org.jboss.ejb3.pool.PoolFactoryRegistry">
-      <property name="factories">
-         <!-- Define each of the registered factories -->
-         <map class="java.util.HashMap" keyClass="java.lang.String"
-            valueClass="java.lang.Class">
-            <!-- ThreadlocalPool -->
-            <entry>
-               <key>ThreadlocalPool</key>
-               <value>org.jboss.ejb3.pool.ThreadlocalPoolFactory</value>
-            </entry>
-            <!-- StrictMaxPool -->
-            <entry>
-               <key>StrictMaxPool</key>
-               <value>org.jboss.ejb3.pool.StrictMaxPoolFactory</value>
-            </entry>
-         </map>
-      </property>
-   </bean>
-   
-   <!-- SFSB JNDI Registrar -->
-   <bean name="org.jboss.ejb3.JndiRegistrar.Session.SFSBJndiRegistrar"
-      class="org.jboss.ejb3.proxy.jndiregistrar.JndiStatefulSessionRegistrar">
-      <constructor>
-         <parameter>
-            org.jboss.ejb3.proxy.objectfactory.session.stateful.StatefulSessionProxyObjectFactory
-         </parameter>
-      </constructor>
-   </bean>
-
-   <!-- SLSB JNDI Registrar -->
-   <bean name="org.jboss.ejb3.JndiRegistrar.Session.SLSBJndiRegistrar"
-      class="org.jboss.ejb3.proxy.jndiregistrar.JndiStatelessSessionRegistrar">
-      <constructor>
-         <parameter>
-            org.jboss.ejb3.proxy.objectfactory.session.stateless.StatelessSessionProxyObjectFactory
-         </parameter>
-      </constructor>
-   </bean>
-     
-</deployment>
\ No newline at end of file

Deleted: projects/ejb3/trunk/profile3_1/src/main/resources/conf/jpa-deployers-jboss-beans.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/jpa-deployers-jboss-beans.xml	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/jpa-deployers-jboss-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,96 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<deployment xmlns="urn:jboss:bean-deployer:2.0">
-   <bean name="DataSourceDependencyResolver" class="org.jboss.as.jpa.resolvers.JBossASDataSourceDependencyResolver"/>
-   
-   <bean name="JavaEEModuleInformer" class="org.jboss.as.javaee.SimpleJavaEEModuleInformer"/>
-   
-   <bean name="JBossSearchStrategy" class="org.jboss.jpa.resolvers.strategy.JBossSearchStrategy"/>
-   
-   <bean name="SpecCompliantSearchStrategy" class="org.jboss.jpa.resolvers.strategy.SpecCompliantSearchStrategy"/>
-   
-   <!--
-      Can be DefaultPersistenceUnitDependencyResolver for spec compliant resolving, 
-      InterApplicationPersistenceUnitDependencyResolver for resolving beyond EARs,
-      or DynamicPersistencePersistenceUnitDependencyResolver which allows configuration via JMX.
-   -->
-   <bean name="PersistenceUnitDependencyResolver" class="org.jboss.jpa.resolvers.DynamicPersistenceUnitDependencyResolver"/>
-   
-   <bean name="XPCResolver" class="org.jboss.ejb3.stateful.EJB3XPCResolver"/>
-   
-   <bean name="PersistenceParsingDeployer" class="org.jboss.jpa.deployers.PersistenceParsingDeployer"/>
-
-   <bean name="PersistenceDeployer" class="org.jboss.jpa.deployers.PersistenceDeployer"/>
-   <bean name="PersistenceUnitDeployer" class="org.jboss.jpa.deployers.PersistenceUnitDeployer">
-      <property name="defaultPersistenceProperties">
-         <map keyClass="java.lang.String" valueClass="java.lang.String">
-            <entry>
-               <key>hibernate.transaction.manager_lookup_class</key>
-               <value>org.hibernate.transaction.JBossTransactionManagerLookup</value>
-            </entry>
-            <!--entry>
-               <key>hibernate.connection.release_mode</key>
-               <value>after_statement</value>
-            </entry-->
-            <!--entry>
-               <key>hibernate.transaction.flush_before_completion</key>
-               <value>false</value>
-            </entry-->
-            <!--entry>
-               <key>hibernate.transaction.auto_close_session</key>
-               <value>false</value>
-            </entry-->
-            <!--entry>
-               <key>hibernate.query.factory_class</key>
-               <value>org.hibernate.hql.ast.ASTQueryTranslatorFactory</value>
-            </entry-->
-            <!--entry>
-               <key>hibernate.hbm2ddl.auto</key>
-               <value>create-drop</value>
-            </entry-->
-            <entry>
-               <key>hibernate.cache.provider_class</key>
-               <value>org.hibernate.cache.HashtableCacheProvider</value>
-            </entry>
-            <!-- Clustered cache with JBoss Cache -->
-            <!--entry>
-               <key>hibernate.cache.region.factory_class</key>
-               <value>org.hibernate.cache.jbc2.JndiMultiplexedJBossCacheRegionFactory</value>
-            </entry>
-            <entry>
-               <key>hibernate.cache.region.jbc2.cachefactory</key>
-               <value>java:CacheManager</value>
-            </entry>
-            <entry>
-               <key>hibernate.cache.region.jbc2.cfg.entity</key>
-               <value>pessimistic-entity</value>
-            </entry>
-            <entry>
-               <key>hibernate.cache.region.jbc2.cfg.query</key>
-               <value>local-query</value>
-            </entry-->
-            <!--entry>
-               <key>hibernate.dialect</key>
-               <value>org.hibernate.dialect.HSQLDialect</value>
-            </entry-->
-            <entry>
-               <key>hibernate.jndi.java.naming.factory.initial</key>
-               <value>org.jnp.interfaces.NamingContextFactory</value>
-            </entry>
-            <entry>
-               <key>hibernate.jndi.java.naming.factory.url.pkgs</key>
-               <value>org.jboss.naming:org.jnp.interfaces</value>
-            </entry>
-            <entry>
-               <key>hibernate.bytecode.use_reflection_optimizer</key>
-               <value>false</value>
-            </entry>
-            <!-- I don't think this is honored, but EJB3Deployer uses it -->
-            <entry>
-               <key>hibernate.bytecode.provider</key>
-               <value>javassist</value>
-            </entry>
-         </map>
-      </property>
-   </bean>
-</deployment>

Deleted: projects/ejb3/trunk/profile3_1/src/main/resources/conf/transactionmanager-beans.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/conf/transactionmanager-beans.xml	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/conf/transactionmanager-beans.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,13 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<deployment xmlns="urn:jboss:bean-deployer:2.0">
-   <!-- JTA -->
-   <bean name="TransactionManager" class="org.jboss.ejb3.embedded.service.SimpleTransactionService">
-      <depends>NamingServer</depends>
-   </bean>
-   
-   <bean name="RealTransactionManager">
-      <constructor factoryMethod="getTransactionManager">
-         <factory bean="TransactionManager"/>
-      </constructor>
-   </bean>
-</deployment>

Copied: projects/ejb3/trunk/profile3_1/src/main/resources/jndi.properties (from rev 83796, projects/ejb3/trunk/profile3_1/src/test/resources/jndi.properties)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/main/resources/jndi.properties	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/main/resources/jndi.properties	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,2 @@
+java.naming.factory.initial=org.jnp.interfaces.LocalOnlyContextFactory
+java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces

Modified: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/common/AbstractProfile3_1_TestCase.java
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface/NoInterfaceStatelessBean.java	2009-02-03 06:27:58 UTC (rev 83796)
+++ projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/NoInterfaceStatelessBean.java	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,49 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source.
- * Copyright 2008, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
-  *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.ejb3.profile3_1.test.nointerface;
-
-import javax.ejb.Remote;
-import javax.ejb.Stateless;
-
-import org.jboss.ejb3.annotation.RemoteBinding;
-
-/**
- * 
- * NoInterfaceStatelessBean
- *
- * @author Jaikiran Pai
- * @version $Revision: $
- */
- at Stateless
-// For initial test adding this Remote interface. Once the
-// profile3_1 framework is ready, since this is "nointerface" testcase
-// we will remove this interface
- at Remote (TestRemote.class)
- at RemoteBinding (jndiBinding="HellJai")
-public class NoInterfaceStatelessBean implements TestRemote
-{
-
-   public String sayHelloFromEJB31(String name)
-   {
-      return "EJB 3.1 says hello to " + name;
-   }
-}

Copied: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSB.java (from rev 83796, projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface/NoInterfaceStatelessBean.java)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSB.java	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSB.java	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,43 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+  *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.ejb3.profile3_1.test.deployment;
+
+import javax.ejb.Local;
+import javax.ejb.Stateless;
+
+/**
+ * 
+ * SimpleSLSB
+ *
+ * @author Jaikiran Pai
+ * @version $Revision: $
+ */
+ at Stateless
+ at Local(SimpleSLSBLocal.class)
+public class SimpleSLSB implements SimpleSLSBLocal
+{
+
+   public String sayHello(String name)
+   {
+      return "Profile3_1 says hello to " + name;
+   }
+}

Copied: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSBLocal.java (from rev 83796, projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface/TestRemote.java)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSBLocal.java	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSBLocal.java	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,34 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+  *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.ejb3.profile3_1.test.deployment;
+
+/**
+ * 
+ * SimpleSLSBLocal
+ *
+ * @author Jaikiran Pai
+ * @version $Revision: $
+ */
+public interface SimpleSLSBLocal
+{
+   String sayHello(String name);
+}


Property changes on: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/SimpleSLSBLocal.java
___________________________________________________________________
Name: svn:mergeinfo
   + 

Deleted: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/TestRemote.java
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface/TestRemote.java	2009-02-03 06:27:58 UTC (rev 83796)
+++ projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/TestRemote.java	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,6 +0,0 @@
-package org.jboss.ejb3.profile3_1.test.nointerface;
-
-public interface TestRemote
-{
-
-}

Deleted: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/unit/NoInterfaceBeanTestCase.java
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface/unit/NoInterfaceBeanTestCase.java	2009-02-03 06:27:58 UTC (rev 83796)
+++ projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/unit/NoInterfaceBeanTestCase.java	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,84 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source.
- * Copyright 2008, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
-  *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.ejb3.profile3_1.test.nointerface.unit;
-
-import javax.naming.Binding;
-import javax.naming.Context;
-import javax.naming.InitialContext;
-import javax.naming.NamingEnumeration;
-
-import org.jboss.ejb3.profile3_1.test.common.AbstractProfile3_1_TestCase;
-import org.jboss.ejb3.profile3_1.test.nointerface.NoInterfaceStatelessBean;
-import org.jboss.logging.Logger;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.Test;
-
-/**
- * NoInterfaceBeanTestCase
- *
- * @author Jaikiran Pai
- * @version $Revision: $
- */
-public class NoInterfaceBeanTestCase extends AbstractProfile3_1_TestCase
-{
-   /**
-    * Logger
-    */
-   private static Logger logger = Logger.getLogger(NoInterfaceBeanTestCase.class);
-
-   @BeforeClass
-   public static void beforeClass() throws Throwable
-   {
-      bootstrap();
-   }
-
-   @AfterClass
-   public static void afterClass() throws Throwable
-   {
-      shutdown();
-   }
-
-   /**
-    * TODO: Jaikiran - This is currently in work-in-progress state. 
-    * The intention of this test (at present) is to ensure that the profile3_1 test framework is ready
-    * for use. This will just test that the bean gets deployed.
-    * @throws Throwable
-    */
-   @Test
-   public void testBeanDeployment() throws Throwable
-   {
-
-      // @see the javadoc of this method for more details about what this is expected to do
-      deploy(NoInterfaceStatelessBean.class);
-      
-      Context ctx = new InitialContext();
-      NamingEnumeration<Binding> bindings = ctx.listBindings("");
-      while (bindings.hasMoreElements())
-      {
-         Binding binding = bindings.nextElement();
-         logger.info("JNDI Binding: " + binding.getName() + " val " + binding.getObject() + " class " + binding.getClass());
-      }
-
-   }
-
-}

Copied: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/unit/Profile3_1_DeploymentTestCase.java (from rev 83796, projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface/unit/NoInterfaceBeanTestCase.java)
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/unit/Profile3_1_DeploymentTestCase.java	                        (rev 0)
+++ projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/unit/Profile3_1_DeploymentTestCase.java	2009-02-04 09:11:31 UTC (rev 83842)
@@ -0,0 +1,86 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+  *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.ejb3.profile3_1.test.deployment.unit;
+
+import javax.naming.Context;
+import javax.naming.InitialContext;
+
+import org.jboss.ejb3.profile3_1.test.common.AbstractProfile3_1_TestCase;
+import org.jboss.ejb3.profile3_1.test.deployment.SimpleSLSBLocal;
+import org.jboss.logging.Logger;
+import org.junit.AfterClass;
+import org.junit.BeforeClass;
+import org.junit.Test;
+
+/**
+ * Profile3_1_DeploymentTestCase
+ * 
+ * Testcase to ensure that the profile3_1 bootstrap loads properly
+ *
+ * @author Jaikiran Pai
+ * @version $Revision: $
+ */
+public class Profile3_1_DeploymentTestCase extends AbstractProfile3_1_TestCase
+{
+   /**
+    * Logger
+    */
+   private static Logger logger = Logger.getLogger(Profile3_1_DeploymentTestCase.class);
+
+   @BeforeClass
+   public static void beforeClass() throws Throwable
+   {
+      bootstrap();
+      startProfile();
+   }
+
+   @AfterClass
+   public static void afterClass() throws Throwable
+   {
+      shutdown();
+   }
+
+   /**
+    * This test ensures that the basic deployment support provided by
+    * profile3_1 component is working
+    * 
+    * @throws Throwable
+    */
+   @Test
+   public void testBeanDeployment() throws Throwable
+   {
+      // Deploy the jar (containing the bean)
+      deploy(Thread.currentThread().getContextClassLoader().getResource("ejb3-profile-test.jar"));
+      logger.info("ejb3-profile-test.jar deployed");
+
+      // lookup the bean
+      Context ctx = new InitialContext();
+      SimpleSLSBLocal bean = (SimpleSLSBLocal) ctx.lookup("SimpleSLSB/local");
+      logger.debug("Successfully looked up bean " + bean);
+
+      // invoke a method
+      String message = bean.sayHello("newuser");
+      logger.debug("Bean returned message = " + message);
+
+   }
+
+}

Modified: projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap/maindeployer.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap/maindeployer.xml	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap/maindeployer.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -52,28 +52,8 @@
    
   <bean name="ManagedDeploymentCreator" class="org.jboss.deployers.plugins.managed.TypedManagedDeploymentCreator" />
   
-  <!--  Classloading deployers -->
-     <bean name="ClassLoadingMetaDataParser" class="org.jboss.deployers.vfs.spi.deployer.SchemaResolverDeployer">
-      <constructor>
-         <parameter>org.jboss.classloading.spi.metadata.ClassLoadingMetaData</parameter>
-      </constructor>
-      <property name="name">jboss-classloading.xml</property>
-      <property name="buildManagedObject">true</property>
-   </bean>
-   <bean name="ClassLoadingDefaultDeployer" class="org.jboss.deployers.plugins.classloading.ClassLoadingDefaultDeployer">
-      <property name="defaultMetaData">
-         <classloading xmlns="urn:jboss:classloading:1.0" export-all="NON_EMPTY" import-all="true"/>
-      </property>
-   </bean>
-   <bean name="InMemoryClassesDeployer" class="org.jboss.deployers.vfs.plugins.classloader.InMemoryClassesDeployer"/>
-   <bean name="ClassLoaderClassPathDeployer" class="org.jboss.deployers.vfs.plugins.classloader.VFSClassLoaderClassPathDeployer"/>
-   <bean name="ClassLoaderDescribeDeployer" class="org.jboss.deployers.vfs.plugins.classloader.VFSClassLoaderDescribeDeployer">
-      <property name="classLoading"><inject bean="ClassLoading"/></property>
-   </bean>
-   <bean name="ClassLoaderDeployer" class="org.jboss.deployers.plugins.classloading.AbstractLevelClassLoaderSystemDeployer">
-      <property name="classLoading"><inject bean="ClassLoading"/></property>
-      <property name="system"><inject bean="ClassLoaderSystem"/></property>
-   </bean>
+
+     
   
   <!-- AOP deployers -->
   <bean name="AOPXMLMetaDataParserDeployer" class="org.jboss.deployers.vfs.spi.deployer.SchemaResolverDeployer">

Modified: projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap.xml
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap.xml	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/test/resources/conf/bootstrap.xml	2009-02-04 09:11:31 UTC (rev 83842)
@@ -6,7 +6,7 @@
 	folder. But unfortunately, the org.jboss.bootstrap.xml.BootstrapParser expects the
 	bootstrap.xml to be present in ServerConfig.SERVER_CONFIG_URL -->
 	
-   <url>bootstrap/classloading.xml</url>
+   <!-- <url>bootstrap/classloading.xml</url> -->
    <url>bootstrap/naming.xml</url>
    <url>bootstrap/maindeployer.xml</url>
    

Deleted: projects/ejb3/trunk/profile3_1/src/test/resources/jndi.properties
===================================================================
--- projects/ejb3/trunk/profile3_1/src/test/resources/jndi.properties	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/test/resources/jndi.properties	2009-02-04 09:11:31 UTC (rev 83842)
@@ -1,2 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.LocalOnlyContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces




More information about the jboss-cvs-commits mailing list
--- projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/common/AbstractProfile3_1_TestCase.java	2009-02-04 08:35:54 UTC (rev 83841)
+++ projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/common/AbstractProfile3_1_TestCase.java	2009-02-04 09:11:31 UTC (rev 83842)
@@ -41,7 +41,8 @@
 /**
  * AbstractProfile3_1_TestCase
  * 
- * This provides the necessary "profile3_1" runtime environment for testcases to run.
+ * This provides the necessary "profile3_1" profile for integration testing of
+ * components that make up this profile.
  *
  * @author Jaikiran Pai
  * @version $Revision: $
@@ -107,13 +108,20 @@
     * This is where we place our configuration files which provide the runtime environment
     * for our "profile3_1". Ex: ejb3-deployer-jboss-beans.xml is placed here
     */
-   protected static final String SERVER_PROFILE3_1_DEPLOYERS_DIR_PATH = "src/main/resources/conf";
+   protected static final String SERVER_PROFILE3_1_DEPLOYERS_DIR_PATH = "src/main/resources/conf/deployers";
+   
+   /**
+    * This is where we place our applications to be deployed. The "applications" can also include
+    * EJB3 remoting connectors, interceptors etc...
+    */
+   protected static final String SERVER_PROFILE3_1_DEPLOY_DIR_PATH = "src/main/resources/conf/deploy";
 
    /**
     * Bootstrap the server.
     * It first creates a server through the bootstrap.xml configuration file
     * and once the server is started, it then deploys the deployers.
     * 
+    * @see #startProfile()
     * @throws Exception
     */
    public static void bootstrap() throws Exception
@@ -125,10 +133,9 @@
       long start = System.currentTimeMillis();
       server.start();
       long end = System.currentTimeMillis();
-      logger.info("Profile3_1 server started in " + (end - start) + " milli sec.");
+      logger.info("Profile3_1 bootstrap started in " + (end - start) + " milli sec.");
 
-      // now deploy the Profile3_1 deployers
-      deploy(new File(SERVER_PROFILE3_1_DEPLOYERS_DIR_PATH).toURL());
+      
    }
 
    /**
@@ -143,6 +150,42 @@
          logger.info("Profile3_1 server has been shutdown");
       }
    }
+   
+   /**
+    * Deploys the deployers and the applications
+    * to start the profile3_1
+    * 
+    * @throws Exception
+    */
+   public static void startProfile() throws Exception
+   {
+      logger.debug("Starting Profile3_1");
+      deployDeployers();
+      logger.debug("Profile3_1 deployers ready");
+      deployApplications();
+      logger.debug("Profile3_1 completely started");
+   }
+   
+   /**
+    * Deploys the deployers 
+    * 
+    * @throws Exception
+    */
+   public static void deployDeployers() throws Exception
+   {
+      // now deploy the Profile3_1 deployers
+      deploy(new File(SERVER_PROFILE3_1_DEPLOYERS_DIR_PATH).toURL());
+   }
+   
+   /**
+    * Deploy the applications (in deploy folder)
+    * 
+    * @throws Exception
+    */
+   public static void deployApplications() throws Exception
+   {
+      deploy(new File(SERVER_PROFILE3_1_DEPLOY_DIR_PATH).toURL());
+   }
 
    /**
     * Create the necessary infrastructure to boot the server. This includes, creating
@@ -228,6 +271,10 @@
     */
    protected static void deploy(URL deployURL) throws Exception
    {
+      if (deployURL == null)
+      {
+         throw new IllegalArgumentException("Null URL passed to deploy");
+      }
       logger.debug("Deploying " + deployURL);
       MainDeployer mainDeployer = getMainDeployer();
       VirtualFile root = VFS.getRoot(deployURL);
@@ -238,32 +285,48 @@
 
    }
    
+//   /**
+//    * Deploys a class.
+//    * 
+//    * TODO: Jaikiran - This is in testing phase, since i am not yet sure whether we have a
+//    * deployer in EJB3 which works only on class instead of .jar, .ear components.
+//    * The main intention to allow deploying a class is to avoid the additional jar/ear creation
+//    * during testcases
+//    * 
+//    * NOT SUPPORTED
+//    * 
+//    * @param deployableClass
+//    * @throws Exception
+//    */
+//   protected static void deploy(Class<?> deployableClass) throws Exception
+//   {
+//      String classFQN = deployableClass.getName();
+//      String klass = classFQN.replaceAll("\\.", "/") + ".class";
+//      if (logger.isTraceEnabled())
+//      {
+//         logger.trace("Deploying class = " + klass);
+//      }
+//      URL classURL =Thread.currentThread().getContextClassLoader().getResource(klass);
+//      if (logger.isTraceEnabled())
+//      {
+//         logger.trace("URL form of class " + classFQN + " is = " + classURL);
+//      }
+//      deploy(classURL);
+//      
+//   }
+   
    /**
-    * Deploys a class.
-    * 
-    * TODO: Jaikiran - This is in testing phase, since i am not yet sure whether we have a
-    * deployer in EJB3 which works only on class instead of .jar, .ear components.
-    * The main intention to allow deploying a class is to avoid the additional jar/ear creation
-    * during testcases
-    * 
-    * 
-    * @param deployableClass
-    * @throws Exception
+    * Deploy a resource
     */
-   protected static void deploy(Class<?> deployableClass) throws Exception
+   protected static void deploy(String resourceName) throws Exception
    {
-      String classFQN = deployableClass.getName();
-      String klass = classFQN.replaceAll("\\.", "/") + ".class";
-      if (logger.isTraceEnabled())
+      if (resourceName == null)
       {
-         logger.trace("Deploying class = " + klass);
+         throw new IllegalArgumentException("Null resourceName passed to deploy");
       }
-      URL classURL =Thread.currentThread().getContextClassLoader().getResource(klass);
-      if (logger.isTraceEnabled())
-      {
-         logger.trace("URL form of class " + classFQN + " is = " + classURL);
-      }
-      deploy(classURL);
+      URL resourceURL = Thread.currentThread().getContextClassLoader().getResource(resourceName);
+      deploy(resourceURL);
+      
    }
 
    /**
@@ -107,13 +108,20 @@
    /**
     * Bootstrap the server.
-    * It first creates a server through the bootstrap.xml configuration file
-    * and once the server is started, it then deploys the deployers.
+    * It first creates a server through the bootstrap.xml. This does not start the profile3_1
+    * (i.e. it does NOT deploy the deployers or the applications). 
     * 

Copied: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment (from rev 83796, projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/nointerface)

Deleted: projects/ejb3/trunk/profile3_1/src/test/java/org/jboss/ejb3/profile3_1/test/deployment/NoInterfaceStatelessBean.java
===================================================================